@@ -18,7 +18,7 @@
 #
 
 ### initial settings of two parameters size and mu in a negative binomial
-### distribution for a numeric optimal searching function optim in R
+### distribution for the numeric optimal searching function optim in R
 SIZE.INIT <- 1
 MU.INIT <- 0.5
 
@@ -27,9 +27,9 @@ TOLERANCE <- 1e-10
 ITER.TOLERANCE <- 1e5
 
 
-### density function of a truncated zero negative binomial distribution
+### density function of a zero-truncated negative binomial distribution
 ### size and mu are two parameters for the negative binomial
-zerotruncated.dnbinom <- function(x, size, mu, log = FALSE)
+dztnb <- function(x, size, mu, log = FALSE)
 {
   ## the density of x in negative binomial
   p <- dnbinom(x, size = size, mu = mu, log = log)
@@ -44,7 +44,7 @@ zerotruncated.dnbinom <- function(x, size, mu, log = FALSE)
   ## the density of non-zero in negative binomial
   q <- 1 - dnbinom(0, size = size, mu = mu)
 
-  ## normalize all non-zero values in negrative binomial to generate ZTNB
+  ## normalize all non-zero values in negrative binomial
   if (log == FALSE) {
     return( p/q )
   } else {
@@ -53,10 +53,10 @@ zerotruncated.dnbinom <- function(x, size, mu, log = FALSE)
 }
 
 
-### zerotruncated negative loglikelihood
-zerotruncated.minus.log.likelihood <- function(n, size, mu)
+### zero-truncated negative loglikelihood
+ztnb.minus.loglikelihood <- function(n, size, mu)
 {
-  prob <- zerotruncated.dnbinom(n[, 1], size, mu, log = TRUE)
+  prob <- dztnb(n[, 1], size, mu, log = TRUE)
 
   ## negative loglikelihood
   prob <- -prob
@@ -65,53 +65,54 @@ zerotruncated.minus.log.likelihood <- function(n, size, mu)
 
 
 ### calculate the negative binomial loglikelihood
-### zero.items is number of items unobserved
-### size and mu are parameters in a negative binomial distribution
-nb.loglikelihood <- function(n, zero.items, size, mu)
+### zero.count is the number of unobserved species
+nb.loglikelihood <- function(n, zero.count, size, mu)
 {
-  ## likelihood of nonzero terms
+  ## loglikelihood for nonzero counts
   log.prob <- dnbinom(n[, 1], size = size, mu = mu, log = TRUE)
   loglikelihood <- log.prob %*% n[, 2]
 
-  ## add items with zero count
+  ## add loglikelihood for zero count
   log.zero.prob <- dnbinom(0, size = size, mu = mu, log = TRUE)
-  loglikelihood <- loglikelihood + zero.items * log.zero.prob
+  loglikelihood <- loglikelihood + zero.count * log.zero.prob
 
   return(loglikelihood)
 }
 
 
 ### EM algorithm to fit the histogram with a negative binomial distribution
-### hist only includes information for observation
-### the number of unobserved items is missing data
+### n is the histogram for observed species
+### the number of unobserved species is the missing data
 preseqR.ztnb.em <- function(n, size=SIZE.INIT, mu=MU.INIT)
 {
   checking.hist(n)
 
+  n[, 1] <- as.numeric(n[, 1])
   n[, 2] <- as.numeric(n[, 2])
-  ## setting the number of unobserved items as 0
   zero.prob <- exp(dnbinom(0, size = size, mu = mu, log = TRUE))
 
-  ## estimate the total number of distinct items
-  observed.items <- sum(n[, 2])
-  L <- observed.items/( 1 - zero.prob )
+  S <- sum(n[, 2])
+  ## estimate the total number of species
+  L <- S / ( 1 - zero.prob )
 
-  ## expected the number of unobservations
-  zero.items <- L*zero.prob
+  ## expected the number of zero counts
+  zero.counts <- L*zero.prob
 
   ## estimated mean and variance
   m <- (n[, 1] %*% n[, 2]) / L
-  v <- ( (n[, 1] - m)^2 %*% n[, 2] + m^2 * zero.items )/(L - 1)
+  v <- ( (n[, 1] - m)^2 %*% n[, 2] + m^2 * zero.counts )/(L - 1)
 
   ## target function f
   f <- function(x) {
-        return( -nb.loglikelihood(n, zero.items, size = x, mu = m)/L )
+        return( -nb.loglikelihood(n, zero.counts, size = x, mu = m)/L )
   }
 
   ## derivative of f
+  ## zero.counts is an external variable that are updated by the EM algorithm
+  ## CHECK IT!
   gr <- function(x)
   {
-    first.term <- ( digamma(x) * zero.items +
+    first.term <- ( digamma(x) * zero.counts +
                     digamma(n[, 1] + x) %*% n[, 2] )/L
     second.term <- digamma(x)
     third.term <- log(x) - log(x + m)
@@ -135,11 +136,11 @@ preseqR.ztnb.em <- function(n, size=SIZE.INIT, mu=MU.INIT)
   ## initialize the negative loglikelihood
   loglikelihood.pre <- Inf
 
-  ## zerotruncated loglikelihood
-  loglikelihood <- zerotruncated.minus.log.likelihood(n, res$par, m)
+  ## zero-truncated loglikelihood
+  loglikelihood <- ztnb.minus.loglikelihood(n, res$par, m)
 
   ## EM algorithm
-  while (( loglikelihood.pre - loglikelihood )/observed.items > TOLERANCE &&
+  while (( loglikelihood.pre - loglikelihood ) / S > TOLERANCE &&
            iter < ITER.TOLERANCE)
   {
     ## update negative loglikelihood
@@ -149,22 +150,16 @@ preseqR.ztnb.em <- function(n, size=SIZE.INIT, mu=MU.INIT)
     size <- res$par
     mu <- m
 
-### E-step: estimate the number of unobserved items
+### E-step: estimate the number of unobserved species
 
-    ## update the probility an item unobserved
     zero.prob <- exp(dnbinom(0, size = size, mu = mu, log = TRUE))
-
-    ## estimate the total number of distinct items
-    L <- observed.items/( 1 - zero.prob )
-
-    ## update expected number of unobserved items
-    zero.items <- L*zero.prob
-
-    ## estimated mean and variance
+    L <- S / ( 1 - zero.prob )
+    zero.counts <- L * zero.prob
     m <- (n[, 1] %*% n[, 2])/L
-    v <- ( (n[, 1] - m)^2 %*% n[, 2] + m^2 * zero.items )/(L - 1)
+    v <- ( (n[, 1] - m)^2 %*% n[, 2] + m^2 * zero.counts )/(L - 1)
 
 ### M step: estimate the parameters size and mu
+
     if (v > m) {
       res <- optim(m^2 / (v - m), f, gr, method = "L-BFGS-B",
              lower = 0.0001, upper = 10000)
@@ -173,37 +168,33 @@ preseqR.ztnb.em <- function(n, size=SIZE.INIT, mu=MU.INIT)
              lower = 0.0001, upper = 10000)
     }
     iter <- iter + 1
-    ## zerotruncated loglikelihood
-    loglikelihood <- zerotruncated.minus.log.likelihood(n, res$par, m)
+    loglikelihood <- ztnb.minus.loglikelihood(n, res$par, m)
   }
   return(list(size = size, mu = mu, loglik = -loglikelihood.pre))
 }
 
 
 ## fitting the negative binoimal distribution to the data by EM algorithm
-## r is a vector of frequencies
-## return an estimator by ZTNB
-ztnb.mincount <- function(n, r=1, size=SIZE.INIT, mu=MU.INIT)
+ztnb.rSAC <- function(n, r=1, size=SIZE.INIT, mu=MU.INIT)
 {
   checking.hist(n)
 
   n[, 2] <- as.numeric(n[, 2])
-  total.sample <- n[, 1] %*% n[, 2]
-  distinct <- sum(n[, 2])
+  S <- sum(n[, 2])
 
   ## estimate parameters
   opt <- preseqR.ztnb.em(n, size, mu)
   size <- opt$size
   mu <- opt$mu
 
-  ## the probability of being sampled in the initial experiment
+  ## the probability of a species observed in the initial sample
   p <- 1 - dnbinom(0, size = size, mu = mu)
 
-  ## L is the estimated total number of distinct items
-  L <- distinct/p
+  ## L is the estimated number of species in total
+  L <- S / p
 
-  f.mincount <- function(t) {
+  f.rSAC <- function(t) {
     L * pnbinom(r - 1, size=size, mu=mu*t, lower.tail=FALSE)
   }
-  f.mincount(1); f.mincount
+  f.rSAC
 }
